local GetTime = GetTime;

local plugin = InfoPanel:AddPlugin();

local combStart, combTime, dmgTotal;
local playerGUID = UnitGUID("player");

-- Constants
local COMBAT_EVENT_PREFIX_SUFFIX = "(.-)_(.+)";

--------------------------------------------------------------------------------------------------------
--                                             Functions                                              --
--------------------------------------------------------------------------------------------------------

-- OnShowTooltip
function plugin:OnShowTooltip(tooltip)
	tooltip:AddLine("DPS Info",1,1,1);
	if (dmgTotal) then
		tooltip:AddDoubleLine("Total Damage",dmgTotal,nil,nil,nil,1,1,1);
		tooltip:AddDoubleLine("Combat Time",InfoPanel.FormatTime2(combTime),nil,nil,nil,1,1,1);
	end
end

-- Show DPS
function plugin:UpdateDPS()
	if (combTime == 0) then
		self:SetText("0");
	else
		self:SetText("%.1f",dmgTotal / combTime);
	end
end

-- Parse combat log events
function plugin:OnCombatEvent(timestamp,event,hideCaster,sourceGUID,sourceName,sourceFlags,sourceRaidFlags,destGUID,destName,destFlags,destRaidFlags,...)
	if (sourceGUID == playerGUID) and (destGUID ~= playerGUID) then
		local prefix, suffix = event:match(COMBAT_EVENT_PREFIX_SUFFIX);
		if (suffix == "DAMAGE" or suffix == "PERIODIC_DAMAGE" or suffix == "SHIELD") then
			--AzMsg(event.." = "..select(prefix == "SWING" and 1 or 4,...));
			dmgTotal = (dmgTotal + select(prefix == "SWING" and 1 or 4,...));
			combTime = (GetTime() - combStart);
			self:UpdateDPS();
		end
	end
end

-- Combat End
function plugin:PLAYER_REGEN_ENABLED()
	self:UnregisterEvent("COMBAT_LOG_EVENT_UNFILTERED");
	combTime = (GetTime() - combStart);
	self:UpdateDPS();
end

-- Combat Start
function plugin:PLAYER_REGEN_DISABLED()
	combStart = GetTime();
	combTime = 0;
	dmgTotal = 0;
	plugin:RegisterEvent("COMBAT_LOG_EVENT_UNFILTERED");
end

-- Combat Log Events -- http://www.wowpedia.org/Events/C#COMBAT_LOG_EVENT_UNFILTERED
function plugin:COMBAT_LOG_EVENT_UNFILTERED(event)
	self:OnCombatEvent(CombatLogGetCurrentEventInfo());
end

--------------------------------------------------------------------------------------------------------
--                                              Finalize                                              --
--------------------------------------------------------------------------------------------------------

plugin:SetText("0");
plugin.icon:SetTexture("Interface\\Icons\\Ability_Warrior_Rampage");
plugin:RegisterEvent("PLAYER_REGEN_ENABLED");
plugin:RegisterEvent("PLAYER_REGEN_DISABLED");