local plugin = InfoPanel:AddPlugin();
local CLASS_COLORS = CUSTOM_CLASS_COLORS or RAID_CLASS_COLORS;

-- Work Vars
local raidHealth, raidMana, unitsWithMana, validMemebers;
local deadCount, afkCount, offlineCount, outsideRange;
local instanceList = {};
local classes = {};

--------------------------------------------------------------------------------------------------------
--                                             Functions                                              --
--------------------------------------------------------------------------------------------------------

-- Function to Scan Units
local function ScanUnit(unit)
	local class, classEng = UnitClass(unit);
	-- Init class table
	if (not classes[class]) then
		local color = CLASS_COLORS[classEng];
		classes[class] = { count = 0, validCount = 0, health = 0, mana = 0, color = ("|cff%.2x%.2x%.2x"):format(color.r*255,color.g*255,color.b*255) };
	end
	classes[class].count = (classes[class].count + 1);
	-- count misc
	if (UnitIsDead(unit) or UnitIsGhost(unit)) then
		deadCount = (deadCount + 1);
	end
	if (UnitIsAFK(unit)) then
		afkCount = (afkCount + 1);
	end
	if (not UnitIsConnected(unit)) then
		offlineCount = (offlineCount + 1);
	end
	if (not UnitIsVisible(unit)) then
		outsideRange = (outsideRange + 1);
	end
	-- Gather Health / Mana Info
	if (not UnitIsDead(unit)) and (not UnitIsGhost(unit)) and (UnitIsConnected(unit)) then
		validMemebers = (validMemebers + 1);
		classes[class].validCount = (classes[class].validCount + 1);

		local unitHealth = (UnitHealth(unit) / UnitHealthMax(unit) * 100);
		raidHealth = (raidHealth + unitHealth);
		classes[class].health = (classes[class].health + unitHealth);

		if (UnitPowerType(unit) == 0) then
			local unitMana = (UnitPower(unit) / UnitPowerMax(unit) * 100);
			raidMana = (raidMana + unitMana);
			classes[class].mana = (classes[class].mana + unitMana);
			unitsWithMana = (unitsWithMana + 1);
		end
	end
end

-- OnShowTooltip
function plugin:OnShowTooltip(tooltip)
--	local numParty, numRaid = GetNumPartyMembers(), GetNumRaidMembers();
--	local members = (numRaid > 0 and numRaid or numParty);
	local numMembers = GetNumGroupMembers() or 0;
	-- Show Instance Lockouts
	if (IsShiftKeyDown()) then
		tooltip:AddLine("Raid Lockouts",1,1,1);
		RequestRaidInfo();
		for i = 1, GetNumSavedInstances() do
			local instanceName, instanceID, instanceReset, instanceDifficulty, locked, extended, instanceIDMostSig, isRaid, maxPlayers, difficultyName = GetSavedInstanceInfo(i)
			if (not instanceList[difficultyName]) then
				instanceList[difficultyName] = {};
			end
			instanceList[difficultyName][#instanceList[difficultyName] + 1] = i;
		end
		for difficultyName, tbl in next, instanceList do
			tooltip:AddLine(" ");
			tooltip:AddLine(difficultyName,0,1,0);
			for index, id in ipairs(tbl) do
				local instanceName, instanceID, instanceReset, instanceDifficulty, locked, extended, instanceIDMostSig, isRaid, maxPlayers, difficultyName = GetSavedInstanceInfo(id)
				tooltip:AddDoubleLine(format("|cffffffff%d|r %s",instanceID,instanceName),instanceReset == 0 and "-" or InfoPanel.FormatTime3(instanceReset),nil,nil,nil,1,1,1);
			end
			wipe(tbl);
		end
	-- Player is Solo :(
	elseif (numMembers == 0) then
		tooltip:AddLine("Group Info",1,1,1);
		tooltip:AddLine("Not in a Raid or Party");
	-- Show Group Info
	else
		tooltip:AddLine("Group Info",1,1,1);
		-- clear
		raidHealth, raidMana, unitsWithMana, validMemebers = 0, 0, 0, 0;
		deadCount, afkCount, offlineCount, outsideRange = 0, 0, 0, 0;
		for class, tbl in next, classes do
			tbl.count = 0;
			tbl.validCount = 0;
			tbl.health = 0;
			tbl.mana = 0;
		end
		-- Loop Members
		local unitPrefix = (IsInRaid() and "raid" or "party");
		for i = 1, numMembers do
			ScanUnit(unitPrefix..i);
		end
		if (unitPrefix == "party") then
			ScanUnit("player");
--			numMembers = (numMembers + 1);	-- Az: unsure if this is needed anymore?
		end
		-- Find Group Index and Leader
--		local leader;
--		if (numRaid > 0) then
--			local playerName = UnitName("player");
--			for i = 1, numRaid do
--				local name, rank, subGroup = GetRaidRosterInfo(i);
--				if (rank == 2) then
--					leader = i;
--				end
--				if (name == playerName) then
--					tooltip:AddDoubleLine("Your Group",subGroup,nil,nil,nil,1,1,1);
--				end
--			end
--		elseif (numParty > 0) then
--			leader = GetPartyLeaderIndex();
--		end
		local leader = 0;
		local playerName = UnitName("player");
		for i = 1, numMembers do
			if (UnitIsGroupLeader(unitPrefix..i)) then
				leader = i;
			end
			local name, rank, subGroup = GetRaidRosterInfo(i);
			if (name == playerName) then
				tooltip:AddDoubleLine("Your Group",subGroup,nil,nil,nil,1,1,1);
			end
		end
		-- Add Tip Lines
		local leaderUnit = (leader == 0 and "player" or (unitPrefix..leader));
		local _, classEng = UnitClass(leaderUnit);
		local color = CLASS_COLORS[classEng];
		tooltip:AddDoubleLine("Leader",UnitName(leaderUnit),nil,nil,nil,color.r,color.g,color.b);
		tooltip:AddLine(" ");
		tooltip:AddDoubleLine("Members",numMembers,nil,nil,nil,1,1,1);
		tooltip:AddDoubleLine("Out of Range",outsideRange == 0 and "-" or outsideRange,nil,nil,nil,1,1,1);
		tooltip:AddDoubleLine("Dead or Ghost",deadCount == 0 and "-" or deadCount,nil,nil,nil,1,1,1);
		tooltip:AddDoubleLine("AFKs",afkCount == 0 and "-" or afkCount,nil,nil,nil,1,1,1);
		tooltip:AddDoubleLine("Offline",offlineCount == 0 and "-" or offlineCount,nil,nil,nil,1,1,1);
		tooltip:AddLine(" ");
		tooltip:AddDoubleLine("Raid Health",(validMemebers > 0 and format("%.2f%%",raidHealth / validMemebers) or ""),nil,nil,nil,0,1,0);
		if (unitsWithMana > 0) then
			tooltip:AddDoubleLine("Raid Mana",format("%.2f%%",raidMana / unitsWithMana),nil,nil,nil,0.4,0.8,0.93);
		end
		tooltip:AddLine(" ");
		for class, tbl in next, classes do
			if (tbl.mana == 0) then
				tooltip:AddDoubleLine(tbl.count..tbl.color.."  "..class,(tbl.validCount > 0 and format("%.2f%%",(tbl.health / tbl.validCount)) or ""),nil,nil,nil,0,1,0);
			else
				tooltip:AddDoubleLine(tbl.count..tbl.color.."  "..class,format("|cff68ccef%.2f%%|cffffffff |||r %.2f%%",(tbl.mana / tbl.validCount),(tbl.health / tbl.validCount)),nil,nil,nil,0,1,0);
			end
		end
	end
end

-- Modifier Key Change -- Az: Bad hack, plugins should be able to request the core to update the tooltip
function plugin:MODIFIER_STATE_CHANGED(key,state)
	if (GameTooltip:IsOwned(self)) then
		self:GetScript("OnEnter")(self);
	end
end

--------------------------------------------------------------------------------------------------------
--                                              Finalize                                              --
--------------------------------------------------------------------------------------------------------

plugin:SetText("Group");
plugin.icon:SetTexture("Interface\\Icons\\Spell_unused2");
plugin:SetScript("OnClick",function(self) ToggleFriendsFrame(4); end);
plugin:RegisterEvent("MODIFIER_STATE_CHANGED");