local plugin = InfoPanel:AddPlugin();
local GetCurrencyInfo = C_CurrencyInfo.GetCurrencyInfo;
local honorStart, honorLast, honorThis;

--------------------------------------------------------------------------------------------------------
--                                             Functions                                              --
--------------------------------------------------------------------------------------------------------

-- OnShowTooltip
function plugin:OnShowTooltip(tooltip)
	tooltip:AddLine("Honor Details",1,1,1);
	local kills = GetPVPSessionStats();
	local _, honorPts = GetCurrencyInfo(HONOR_CURRENCY);
	local _, arenaPts = GetCurrencyInfo(CONQUEST_CURRENCY);

	-- Session/Zone Honor
	if (honorPts) and (arenaPts) then
--		tooltip:AddDoubleLine("This Session's Honor",honorPts - sessionHonor,nil,nil,nil,1,1,1);
		tooltip:AddDoubleLine("This Session's Honor",honorPts - honorStart,nil,nil,nil,1,1,1);
		if (honorThis) then
--			tooltip:AddDoubleLine("This Zone's Honor",points - honorThisZone,nil,nil,nil,1,1,1);
			tooltip:AddDoubleLine("This Zone's Honor",honorPts - honorThis,nil,nil,nil,1,1,1);
			if (honorLast) then
--				tooltip:AddDoubleLine("Last Zone's Honor",honorThisZone - honorPrevZone,nil,nil,nil,1,1,1);
				tooltip:AddDoubleLine("Last Zone's Honor",honorThis - honorLast,nil,nil,nil,1,1,1);
			end
		end
	end

	-- Today's values
--	tooltip:AddLine(" ");
--	tooltip:AddDoubleLine("Today's Kills",kills,nil,nil,nil,1,1,1);
--	tooltip:AddDoubleLine("Today's Points",points,nil,nil,nil,1,1,1);
--	tooltip:AddLine(" ");
	-- Yesterday's values
--	local kills, points = GetPVPYesterdayStats();
--	tooltip:AddDoubleLine("Yesterday's Kills",kills,nil,nil,nil,1,1,1);
--	tooltip:AddDoubleLine("Yesterday's Points",points,nil,nil,nil,1,1,1);

	-- Lifetime stats
	tooltip:AddLine(" ");
	local highestRank;
	kills, highestRank = GetPVPLifetimeStats();
	tooltip:AddDoubleLine("Lifetime Kills",kills,nil,nil,nil,1,1,1);
	tooltip:AddDoubleLine("Highest Rank",highestRank,nil,nil,nil,1,1,1);

	-- Rank
--	local rankName, rankNumber = GetPVPRankInfo(highestRank);
--	if ( not rankName ) then
--		rankName = NONE;
--	end
--	tooltip:AddDoubleLine("Rank Name",rankName,nil,nil,nil,1,1,1);
--	tooltip:AddDoubleLine("Rank Number",rankNumber,nil,nil,nil,1,1,1);

	-- Points
	tooltip:AddLine(" ");
	tooltip:AddLine("Currency",1,1,1);
	tooltip:AddDoubleLine(HONOR_POINTS,honorPts,nil,nil,nil,1,1,1);
	tooltip:AddDoubleLine(ARENA_POINTS,arenaPts,nil,nil,nil,1,1,1);

	-- World PVP Area Wait Time
	local worldBGs = GetNumWorldPVPAreas();
	if (worldBGs and worldBGs > 0) then
		tooltip:AddLine(" ");
		tooltip:AddLine("World PVP Areas",1,1,1);
		for i = 1, worldBGs do
			local id, localizedName, isActive, canQueue, startTime, canEnter, minLevel, maxLevel = GetWorldPVPAreaInfo(i);
			local timeText = (isActive and "Now!") or (startTime and InfoPanel.FormatTime2(startTime)) or UNKNOWN;
			tooltip:AddDoubleLine(localizedName,timeText,nil,nil,nil,1,1,1);
		end
	end

	-- PvP Time
	local pvpTime = GetPVPTimer();
	if (pvpTime) and (pvpTime < 301000) then
		tooltip:AddLine(" ");
		tooltip:AddDoubleLine("PvP Flag Time",InfoPanel.FormatTime(pvpTime / 1000),nil,nil,nil,1,1,1);
	end;
end

-- Zone Change
function plugin:ZONE_CHANGED_NEW_AREA(event)
	honorLast = honorThis;
	local _, honorPts = GetCurrencyInfo(HONOR_CURRENCY);
	honorThis = honorPts;
end
plugin.PLAYER_ENTERING_WORLD = plugin.ZONE_CHANGED_NEW_AREA;

-- Honor Update
function plugin:CURRENCY_DISPLAY_UPDATE(event)
	local _, honorPts = GetCurrencyInfo(HONOR_CURRENCY);
	self:SetText(honorPts);
end

-- Login
function plugin:PLAYER_LOGIN(event)
	local _, honorPts = GetCurrencyInfo(HONOR_CURRENCY);
	honorStart = honorPts;
	self:SetText(honorStart);
	self[event] = nil;
end

--------------------------------------------------------------------------------------------------------
--                                              Finalize                                              --
--------------------------------------------------------------------------------------------------------

plugin.icon:SetTexture(UnitFactionGroup("player") == "Alliance" and "Interface\\Icons\\INV_BannerPVP_02" or "Interface\\Icons\\INV_BannerPVP_01");
--plugin:SetScript("OnClick",function(self) ToggleFrame(PVPFrame); end);
plugin:RegisterEvent("PLAYER_LOGIN");
plugin:RegisterEvent("CURRENCY_DISPLAY_UPDATE");
--plugin:RegisterEvent("KNOWN_CURRENCY_TYPES_UPDATE");

plugin:RegisterEvent("ZONE_CHANGED_NEW_AREA");
--plugin:RegisterEvent("PLAYER_ENTERING_WORLD");