local _, classID = UnitClass("player");
if (classID == "MAGE" or classID == "WARLOCK" or classID == "PRIEST") then
	return;
end

local plugin = InfoPanel:AddPlugin();
local attackSpeed, critChance, attackPower, hasBattleShout, attackPowerMax;
local GetAP, GetCrit, GetSpeed;
local battleShout = GetSpellInfo(6673);

--------------------------------------------------------------------------------------------------------
--                                           Button Scripts                                           --
--------------------------------------------------------------------------------------------------------

-- OnShowTooltip
function plugin:OnShowTooltip(tooltip)
	tooltip:AddLine("Melee Info",1,1,1);

	tooltip:AddDoubleLine("Attack Speed",format("%.2f",attackSpeed),nil,nil,nil,1,1,1);
	tooltip:AddDoubleLine("Crit Chance",format("%.2f%%",critChance),nil,nil,nil,1,1,1);
	tooltip:AddDoubleLine("Hit Chance",format("%.2f%%",GetCombatRatingBonus(CR_HIT_MELEE) + GetHitModifier()),nil,nil,nil,1,1,1);
	tooltip:AddDoubleLine("Attack Power",attackPower,nil,nil,nil,1,1,1);
	tooltip:AddDoubleLine("Max Session AP",attackPowerMax,nil,nil,nil,attackPowerMax > attackPower and 0 or 1,1,attackPowerMax > attackPower and 0 or 1);

	local lowDmg, hiDmg, offlowDmg, offhiDmg, posBuff, negBuff, percentmod = UnitDamage("player");
	local _, offhandSpeed = GetSpeed("player")
	local hasOffhand = C_PaperDollInfo.OffhandHasWeapon();
	tooltip:AddLine(" ");
	tooltip:AddLine("Weapon Damage",1,1,1);
	tooltip:AddDoubleLine("Modifier",format("%.1f%%",percentmod * 100),nil,nil,nil,percentmod == 1 and 1 or 0,1,percentmod == 1 and 1 or 0);
	tooltip:AddDoubleLine("Mainhand",format("%.1f - %.1f",lowDmg,hiDmg),nil,nil,nil,1,1,1);
	if (hasOffhand) then
		tooltip:AddDoubleLine("Offhand",format("%.1f - %.1f",offlowDmg,offhiDmg),nil,nil,nil,1,1,1);
	end
	tooltip:AddDoubleLine("Mainhand DPS",format("%.1f",(lowDmg + hiDmg) / 2 / attackSpeed),nil,nil,nil,1,1,1);
	if (hasOffhand) then
		tooltip:AddDoubleLine("Offhand DPS",format("%.1f",(offlowDmg + offhiDmg) / 2 / offhandSpeed),nil,nil,nil,1,1,1);
	end
end

-- OnClick
local function OnClick(self,button)
	local editBox = ChatEdit_GetActiveWindow();
	if (editBox) and (editBox:IsVisible()) then
		editBox:Insert(format("%.2f%% Crit, %d AP",critChance,attackPower));
	end
end

--------------------------------------------------------------------------------------------------------
--                                               Events                                               --
--------------------------------------------------------------------------------------------------------

function plugin:UpdateDisplay()
	self:SetText("|cffffffff%.2f  |cff80c0ff%.2f%%  %s%d",attackSpeed,critChance,(hasBattleShout and "|cff52ff52" or "|cffff5252"),attackPower);
end

-- AP Change
function plugin:UNIT_ATTACK_POWER(event)
	local base, posBuff, negBuff = GetAP("player");
	attackPower = max(0,base + posBuff + negBuff);
	if (attackPower > attackPowerMax) then
		attackPowerMax = attackPower;
	end
	self:UpdateDisplay();
end
plugin.UNIT_RANGED_ATTACK_POWER = plugin.UNIT_ATTACK_POWER;

-- Attack Speed Change (show main hand only)
function plugin:UNIT_ATTACK_SPEED(event)
	attackSpeed = GetSpeed("player");
	self:UpdateDisplay();
end

-- Damage Mods Change (crit chance etc)
function plugin:PLAYER_DAMAGE_DONE_MODS(event)
	critChance = GetCrit();
	self:UpdateDisplay();
end

-- Check for BattleShout
function plugin:UNIT_AURA(event,unit)
	if (unit == "player") then
		hasBattleShout = InfoPanel:UnitHasAura("player",battleShout);
		self:UpdateDisplay();
	end
end

-- Player Died
function plugin:PLAYER_DEAD(event)
	hasBattleShout = nil;
	self:UpdateDisplay();
end

-- Login Event
function plugin:PLAYER_LOGIN(event)
	hasBattleShout = (classID ~= "WARRIOR") or (InfoPanel:UnitHasAura("player",battleShout));

	local base, posBuff, negBuff = GetAP("player");
	attackPower = max(0,base + posBuff + negBuff);
	critChance = GetCrit();
	attackSpeed = GetSpeed("player");
	attackPowerMax = attackPower;

	self[event] = nil;
	self:UnregisterEvent(event);
	self:UpdateDisplay();
end

--------------------------------------------------------------------------------------------------------
--                                              Finalize                                              --
--------------------------------------------------------------------------------------------------------

do
	plugin.icon:SetTexture("Interface\\Icons\\Ability_Warrior_Battleshout");
	plugin:SetScript("OnClick",OnClick);

	GetAP = (classID == "HUNTER" and UnitRangedAttackPower or UnitAttackPower);
	GetCrit = (classID == "HUNTER" and GetRangedCritChance or GetCritChance);
	GetSpeed = (classID == "HUNTER" and UnitRangedDamage or UnitAttackSpeed);

	if (classID == "WARRIOR") then
		plugin:RegisterEvent("UNIT_AURA");
		plugin:RegisterEvent("PLAYER_DEAD");
	else
		plugin.UNIT_AURA = nil;
		plugin.PLAYER_DEAD = nil;
	end
	if (classID == "HUNTER") then
		plugin:RegisterEvent("UNIT_RANGED_ATTACK_POWER");
	else
		plugin:RegisterEvent("UNIT_ATTACK_POWER");
	end
	plugin:RegisterEvent("PLAYER_DAMAGE_DONE_MODS");
	plugin:RegisterEvent("UNIT_ATTACK_SPEED");
	plugin:RegisterEvent("PLAYER_LOGIN");
end