local plugin = InfoPanel:AddPlugin();
local sessionStart = GetTime();
local moneyStart, moneyLast, moneyGain, moneyLoss;

--------------------------------------------------------------------------------------------------------
--                                             Functions                                              --
--------------------------------------------------------------------------------------------------------

-- OnShowTooltip
function plugin:OnShowTooltip(tooltip)
	local moneyNow = GetMoney();
	tooltip:AddLine("Money Info",1,1,1);
	tooltip:AddDoubleLine("Starting Money",InfoPanel.FormatCurrency(moneyStart,12),nil,nil,nil,1,1,1);
	if (moneyGain ~= 0) or (moneyLoss ~= 0) then
		local balanceText = (moneyNow > moneyStart) and "Gain" or "Loss";
		local moneyPerHour = (moneyNow - moneyStart) / ((GetTime() - sessionStart) / 60 / 60);
		tooltip:AddDoubleLine("Money Loss",InfoPanel.FormatCurrency(moneyLoss,12),nil,nil,nil,1,1,1);
		tooltip:AddDoubleLine("Money Gain",InfoPanel.FormatCurrency(moneyGain,12),nil,nil,nil,1,1,1);
		tooltip:AddLine(" ");
		tooltip:AddLine("Totals",1,1,1);
		tooltip:AddDoubleLine("Money Profit "..balanceText,InfoPanel.FormatCurrency(abs(moneyGain - moneyLoss),12),nil,nil,nil,1,1,1);
		tooltip:AddDoubleLine("Money "..balanceText.." / Hour",InfoPanel.FormatCurrency(floor(abs(moneyPerHour)),12),nil,nil,nil,1,1,1);
	end
	-- Vendor Trash
	local count, countTotal, value = 0, 0, 0;
	for bag = 0, NUM_BAG_SLOTS do
		for slot = 1, GetContainerNumSlots(bag) do
			local link = GetContainerItemLink(bag,slot);
			local _, stackSize = GetContainerItemInfo(bag,slot);
			if (link) then
				local itemName, itemLink, itemRarity, itemLevel, itemMinLevel, itemType, itemSubType, itemStackCount, itemEquipLoc, itemTexture, itemSellPrice = GetItemInfo(link);
				if (itemRarity == 0) then
					count = (count + 1);
					countTotal = (countTotal + stackSize);
					value = (value + itemSellPrice * stackSize);
				end
			end
		end
	end
	if (count > 0) then
		tooltip:AddLine(" ");
		tooltip:AddLine("Vendor Trash",1,1,1);
		tooltip:AddDoubleLine("Grey Items",count.." ("..countTotal..")",nil,nil,nil,1,1,1);
		tooltip:AddDoubleLine("Total Worth",InfoPanel.FormatCurrency(value,12),nil,nil,nil,1,1,1);
	end
end

-- OnClick
local function OnClick(self,button)
	local editBox = ChatEdit_GetActiveWindow();
	if (editBox) and (editBox:IsVisible()) then
		editBox:Insert(GetCoinText(moneyLast));
	elseif (IsShiftKeyDown()) and (button == "RightButton") then
		sessionStart = GetTime();
		moneyStart = GetMoney();
		moneyLast = moneyStart;
		moneyGain, moneyLoss = 0, 0;
		if (GameTooltip:IsOwned(self)) then
			self:GetScript("OnEnter")(self);
		end
	end
end

-- Money Change
function plugin:PLAYER_MONEY(event)
	local moneyNow = GetMoney();
	local diff = (moneyNow - moneyLast);
	if (diff >= 0) then
		moneyGain = (moneyGain + diff);
	else
		moneyLoss = (moneyLoss - diff);
	end
	self:SetText(GetCoinTextureString(moneyNow,16));
	moneyLast = moneyNow;
end

-- Login
function plugin:PLAYER_LOGIN(event)
	moneyStart = GetMoney();
	moneyLast = moneyStart;
	moneyGain, moneyLoss = 0, 0;
	self:UnregisterEvent(event);
	self:RegisterEvent("PLAYER_MONEY");
	self[event] = nil;
	self:PLAYER_MONEY();
end

--------------------------------------------------------------------------------------------------------
--                                              Finalize                                              --
--------------------------------------------------------------------------------------------------------

plugin.icon:SetTexture("Interface\\Icons\\INV_Misc_Coin_01");
plugin:SetScript("OnClick",OnClick);
plugin:RegisterEvent("PLAYER_LOGIN");