if (UnitLevel("player") == MAX_PLAYER_LEVEL) then
	return;
end

local plugin = InfoPanel:AddPlugin();
local sessionStart;
local xpNow, xpMax;
local xpLast, xpLastMax;
local xpSession, xpCombat, xpGain;

--------------------------------------------------------------------------------------------------------
--                                          Helper Functions                                          --
--------------------------------------------------------------------------------------------------------

-- Splash Message
local function ScreenSplash(header,subtext,r,g,b)
	-- Set Header, Subtext and colors
	ZoneTextString:SetText(header);
	ZoneTextString:SetTextColor(r,g,b);
	SubZoneTextString:SetText(subtext);
	SubZoneTextString:SetTextColor(r,g,b);
	-- Clear this so it wont show: Alliance/Horde/Contested territory or Sanctuary
	PVPInfoTextString:SetText("");
	PVPArenaTextString:SetText("");
	-- Show Frames
	ZoneTextFrame.startTime = GetTime();
	ZoneTextFrame:Show();
	SubZoneTextFrame.startTime = GetTime();
	SubZoneTextFrame:Show();
end

-- Reset XP Variables
local function ResetXPValues()
	sessionStart = GetTime();
	xpNow, xpMax = UnitXP("player"), UnitXPMax("player");
	xpLast, xpLastMax = xpNow, xpMax;
	xpSession, xpCombat, xpGain = 0, 0, nil;
	plugin:SetText("%.2f%%",xpNow / xpMax * 100);
end

--------------------------------------------------------------------------------------------------------
--                                              Events                                                --
--------------------------------------------------------------------------------------------------------

-- OnShowTooltip
function plugin:OnShowTooltip(tooltip)
	tooltip:AddLine("Experience Info",1,1,1);
	tooltip:AddDoubleLine("Current XP",xpNow,nil,nil,nil,1,1,1);
	tooltip:AddDoubleLine("Maximum XP",xpMax,nil,nil,nil,1,1,1);
	tooltip:AddDoubleLine("XP to Next Level",xpMax - xpNow,nil,nil,nil,1,1,1);
	local xpRest = GetXPExhaustion();
	if (xpRest) then
		tooltip:AddDoubleLine("Rested XP",xpRest,nil,nil,nil,0,1,0);
		tooltip:AddDoubleLine("Rested Percentage",format("%.1f%%",xpRest / xpMax * 100),nil,nil,nil,0,1,0);
	end
	-- Any gain at all?
	if (xpGain) then
		tooltip:AddLine(" ");
		tooltip:AddDoubleLine("Last XP Gain",xpGain,nil,nil,nil,1,1,1);
		tooltip:AddDoubleLine("Equal Gains to Level",format("%.2f",(xpMax - xpNow) / xpGain),nil,nil,nil,1,1,1);
		tooltip:AddDoubleLine("Gain Percentage",format("%.2f%%",xpGain / xpMax * 100),nil,nil,nil,1,1,1);
		tooltip:AddLine(" ");
		tooltip:AddDoubleLine("Last Combat XP Gain",xpCombat,nil,nil,nil,1,1,1);
		tooltip:AddDoubleLine("Gain Percentage",format("%.2f%%",xpCombat / xpMax * 100),nil,nil,nil,1,1,1);
	end
	-- Sessions
	if (xpSession > 0) then
		local xpPerHour = (xpSession / ((GetTime() - sessionStart) / 3600));
		tooltip:AddLine(" ");
		tooltip:AddDoubleLine("Session XP Gain",xpSession,nil,nil,nil,1,1,1);
		tooltip:AddDoubleLine("Gain Percentage",format("%.2f%%",xpSession / xpMax * 100),nil,nil,nil,1,1,1);
		tooltip:AddLine(" ");
		tooltip:AddDoubleLine("XP Gain Per Hour",format("%.1f",xpPerHour),nil,nil,nil,1,1,1);
		tooltip:AddDoubleLine("Time to Next Level",InfoPanel.FormatTime3((xpMax - xpNow) / xpPerHour * 3600),nil,nil,nil,1,1,1);
	end
	-- XP Disabled?
	if (IsXPUserDisabled()) then
		tooltip:AddLine("XP Gain Disabled",1,0.25,0.25);
	end
end

-- Login
function plugin:PLAYER_LOGIN(event)
	ResetXPValues();
	self:UnregisterEvent(event);
	self[event] = nil;
end

-- XP Update
function plugin:PLAYER_XP_UPDATE(event)
	xpNow, xpMax = UnitXP("player"), UnitXPMax("player");
	-- We must check if there truely was an XP update, because when you level, it will somehow broadcast two "PLAYER_XP_UPDATE" events.
	if (xpNow == xpLast) and (xpMax == xpLastMax) then
		return;
	end
	xpGain = (xpMax == xpLastMax) and (xpNow - xpLast) or (xpLastMax - xpLast + xpNow); -- Changed this as the previous evaluation would fail if over 1 levels worth of xp was gained in one go.
	xpSession = (xpSession + xpGain);
	xpCombat = (xpCombat + xpGain);
	xpLast, xpLastMax = xpNow, xpMax;
	self:SetText("%.2f%%",xpNow / xpMax * 100);
end

-- One Up!
function plugin:PLAYER_LEVEL_UP(event,level)
	ScreenSplash("Level "..level,"Congratulations!",0.5,0.75,1);
end

-- Combat Start
function plugin:PLAYER_REGEN_DISABLED(event)
	xpCombat = 0;
end

-- OnClick
local function OnClick(self,button)
	local editBox = ChatEdit_GetActiveWindow();
	if (editBox) and (editBox:IsVisible()) then
		editBox:Insert(format("%d / %d (%.2f%%)",xpNow,xpMax,xpNow / xpMax * 100));
	elseif (IsShiftKeyDown()) and (button == "RightButton") then
		ResetXPValues();
		AzMsg("|2InfoPanel|r: Experience Info has been reset");
		if (GameTooltip:IsOwned(self)) then
			self:GetScript("OnEnter")(self);
		end
	end
end

--------------------------------------------------------------------------------------------------------
--                                              Finalize                                              --
--------------------------------------------------------------------------------------------------------

--plugin.icon:SetTexture("Interface/Icons/Spell_Fire_FelFlameRing");
plugin.icon:SetTexture("Interface/Icons/XP_ICON");
--plugin.icon:SetTexture("Interface/Icons/Garr_CurrencyIcon-Xp");


plugin:SetScript("OnClick",OnClick);
plugin:RegisterEvent("PLAYER_LOGIN");
plugin:RegisterEvent("PLAYER_XP_UPDATE");
plugin:RegisterEvent("PLAYER_LEVEL_UP");
plugin:RegisterEvent("PLAYER_REGEN_DISABLED");